==> address_suggestion-1.0.4.tar.gz: address_suggestion/src/Plugin/AddressProvider/VNPost.php <==
<?php

namespace Drupal\address_suggestion\Plugin\AddressProvider;

use Drupal\address_suggestion\AddressProviderBase;
use Drupal\Component\Serialization\Json;

/**
 * Defines a Vietnam post plugin for address_autocomplete.
 *
 * @package Drupal\address_suggestion\Plugin\AddressProvider
 * @AddressProvider(
 *   id = "vnpost",
 *   label = @Translation("Vietnam post"),
 * )
 */
class VNPost extends AddressProviderBase {

  /**
   * {@inheritDoc}
   */
  public function processQuery($string, $settings) {
    $results = [];

    $token = $settings['api_key'];
    if (empty($string) && empty($token)) {
      return $results;
    }
    if (!empty($settings['countryName'])) {
      $string .= ', ' . $settings['countryName'];
    }
    if (!empty($settings['country'])) {
      $country = $settings['country'];
    }
    $url = !empty($settings['endpoint']) ? $settings['endpoint'] : 'https://maps.vnpost.vn/api/autocomplete';
    $url .= '?apikey=' . $token . '&api-version=1.1&layers=address&size=10&text=' . $string;

    $response = $this->client->request('GET', $url);
    $content = Json::decode($response->getBody());
    // Some country have format Street number street name.
    $countryFormatSpecial = ['FR', 'CA', 'IE', 'IN', 'IL', 'HK', 'MY', 'OM',
      'NZ', 'PH', 'SA', 'SE', 'SG', 'LK', 'TH', 'UK', 'US', 'VN',
    ];
    $subdivisions = \Drupal::service('address.subdivision_repository')
      ->getList(['VN'], 'vi');
    $province = array_flip($subdivisions);
    if (!empty($content['code']) && $content['code'] == 'OK') {
      foreach ($content['data']["features"] as $key => $feature) {
        $properties = $feature["properties"];
        $city = str_replace(['Thành Phố '], '', $properties["region"]);
        // Exception.
        if ($city == 'Hồ Chí Minh') {
          $city = 'Thành phố Hồ Chí Minh';
        }
        $results[$key]['street_name'] = $properties["label"];
        $results[$key]['town_name'] = $properties["county"];
        $results[$key]['district'] = $properties["locality"];
        $results[$key]['state'] = $province[$city];
        $results[$key]['zip_code'] = $properties["smartcode"];
        $results[$key]['label'] = $properties["name"];
        $results[$key]['location'] = [
          'longitude' => $feature["geometry"]["coordinates"][0],
          'latitude' => $feature["geometry"]["coordinates"][1],
        ];
      }
    }

    return $results;
  }

}

==> address_suggestion-1.0.5.tar.gz: address_suggestion/src/Plugin/AddressProvider/VNPost.php <==
<?php

namespace Drupal\address_suggestion\Plugin\AddressProvider;

use Drupal\address_suggestion\AddressProviderBase;
use Drupal\Component\Serialization\Json;

/**
 * Defines a Vietnam post plugin for address_autocomplete.
 *
 * @package Drupal\address_suggestion\Plugin\AddressProvider
 * @AddressProvider(
 *   id = "vnpost",
 *   label = @Translation("Vietnam post"),
 * )
 */
class VNPost extends AddressProviderBase {

  /**
   * {@inheritDoc}
   */
  public function processQuery($string, $settings) {
    $results = [];

    $token = $settings['api_key'];
    if (empty($string) && empty($token)) {
      return $results;
    }
    $url = !empty($settings['endpoint']) ? $settings['endpoint'] : 'https://maps.vnpost.vn/api/autocomplete';
    $size = !empty($settings['limit']) ? $settings['limit'] : 10;
    $query = [
      'apikey' => $token,
      'api-version' => '1.1',
      'layers' => 'address',
      'size' => $size,
      'text' => $string,
    ];
    $url .= '?' . http_build_query($query);
    \Drupal::logger('vnpost')->error($url);
    $response = $this->client->request('GET', $url);
    $content = Json::decode($response->getBody());
    $subdivisions = \Drupal::service('address.subdivision_repository')
      ->getList(['VN'], 'vi');
    $province = array_flip($subdivisions);
    if (!empty($content['code']) && $content['code'] == 'OK') {
      foreach ($content['data']["features"] as $key => $feature) {
        $properties = $feature["properties"];
        if (strpos($properties["region"], 'Hồ Chí Minh') === FALSE) {
          $city = str_replace(['Thành Phố '], '', $properties["region"]);
        }
        // Exception 'Hồ Chí Minh'.
        $results[$key]['street_name'] = $properties["label"];
        $results[$key]['town_name'] = $properties["county"];
        $results[$key]['district'] = $properties["locality"];
        if (!empty($province[$city])) {
          $results[$key]['state'] = $province[$city];
        }
        if (!empty($properties["postcode"])) {
          $results[$key]['zip_code'] = $properties["postcode"];
        }
        $results[$key]['name'] = $properties["name"];
        $results[$key]['label'] = $properties["label"];
        $results[$key]['location'] = [
          'longitude' => $feature["geometry"]["coordinates"][0],
          'latitude' => $feature["geometry"]["coordinates"][1],
        ];
      }
    }

    return $results;
  }

}
